==> blesta-5.10.2.zip: blesta/plugins/domains/language/el_gr/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.el_gr
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.!success.change_auto_renewal'] = 'Η αυτόματη ανανέωση domain έχει ενημερωθεί!';
$lang['AdminMain.!success.domain_renewal'] = 'Ο τομέας ανανεώθηκε!';
$lang['AdminMain.!success.update_nameservers'] = 'Οι διακομιστές ονομάτων τομέα έχουν ενημερωθεί!';
$lang['AdminMain.!success.domains_pushed'] = 'Οι επιλεγμένοι τομείς μεταφέρθηκαν επιτυχώς στον νέο πελάτη.';
$lang['AdminMain.index.page_title'] = 'Πελάτης #%1$s Domains';
$lang['AdminMain.index.boxtitle_domains'] = 'Τομείς';
$lang['AdminMain.index.heading_addons'] = 'Πρόσθετα';
$lang['AdminMain.index.heading_status'] = 'Κατάσταση';
$lang['AdminMain.index.heading_domain'] = 'Τομέας';
$lang['AdminMain.index.heading_term'] = 'Όρος';
$lang['AdminMain.index.heading_datecreated'] = 'Ημερομηνία δημιουργίας';
$lang['AdminMain.index.heading_daterenews'] = 'Ημερομηνία Ανανεώνει';
$lang['AdminMain.index.heading_dateexpires'] = 'Ημερομηνία Λήξης';
$lang['AdminMain.index.heading_datesuspended'] = 'Ημερομηνία αναστολής';
$lang['AdminMain.index.heading_datecanceled'] = 'Ημερομηνία Ακύρωσης';
$lang['AdminMain.index.heading_options'] = 'Επιλογές';
$lang['AdminMain.index.category_active'] = 'Ενεργό';
$lang['AdminMain.index.category_pending'] = 'Εκκρεμεί';
$lang['AdminMain.index.category_suspended'] = 'Αναστολή';
$lang['AdminMain.index.category_canceled'] = 'Ακυρώθηκε';
$lang['AdminMain.index.categorylink_newservice'] = 'Νέος τομέας';
$lang['AdminMain.index.recurring_term'] = '%1$s %2$s @ %3$s';
$lang['AdminMain.index.option_parent'] = 'Γονέας';
$lang['AdminMain.index.option_manage'] = 'Διαχείριση';
$lang['AdminMain.index.option_delete'] = 'Διαγραφή';
$lang['AdminMain.index.confirm_delete'] = 'Είστε σίγουροι ότι θέλετε να διαγράψετε αυτή την υπηρεσία;';
$lang['AdminMain.index.no_results'] = 'Δεν υπάρχουν υπηρεσίες με αυτό το καθεστώς.';
$lang['AdminMain.index.text_never'] = 'Ποτέ';
$lang['AdminMain.index.text_on'] = 'Στο';
$lang['AdminMain.index.text_off'] = 'Off';
$lang['AdminMain.index.change_auto_renewal'] = 'Αλλαγή αυτόματης ανανέωσης';
$lang['AdminMain.index.domain_renewal'] = 'Ανανέωση τομέα';
$lang['AdminMain.index.update_nameservers'] = 'Ενημέρωση διακομιστών ονομάτων';
$lang['AdminMain.index.domain_push_to_client'] = 'Πίεση στον πελάτη';
$lang['AdminMain.index.field_actionsubmit'] = 'Υποβολή';
$lang['AdminMain.domains.action.field_years'] = 'Έτη';
$lang['AdminMain.domains.action.field_nameservers'] = 'Διακομιστές ονομάτων';
$lang['AdminMain.domains.action.field_client'] = 'Πελάτης';
$lang['AdminMain.getfilters.any'] = 'Οποιοδήποτε';
$lang['AdminMain.getfilters.field_package_name'] = 'TLD';
$lang['AdminMain.getfilters.field_service_meta'] = 'Όνομα τομέα';
$lang['AdminMain.!success.domains_unparented'] = 'Τα επιλεγμένα domains αφαιρέθηκαν από τις γονικές τους υπηρεσίες και η τιμή επαναρυθμίστηκε με επιτυχία!';
$lang['AdminMain.!success.domain_register'] = 'Ο τομέας καταχωρήθηκε με επιτυχία!';
$lang['AdminMain.!success.domain_transfer'] = 'Ο τομέας μεταφέρθηκε με επιτυχία!';
$lang['AdminMain.!success.domain_add'] = 'Ο τομέας έχει προστεθεί επιτυχώς!';
$lang['AdminMain.!success.service_edited'] = 'Ο τομέας ενημερώθηκε με επιτυχία!';
$lang['AdminMain.!error.unsupported_domain'] = 'Το όνομα τομέα δεν υποστηρίζεται.';
$lang['AdminMain.index.unparent'] = 'Unparent και Επαναφορά τιμής';
$lang['AdminMain.add.boxtitle_client'] = 'Πελάτης #%1$s';
$lang['AdminMain.add.boxtitle_add'] = 'Προσθήκη τομέα: %1$s';
$lang['AdminMain.add.link_viewclient'] = 'Προβολή πελάτη';
$lang['AdminMain.add.field_transfer'] = 'Μεταφορά';
$lang['AdminMain.add.field_register'] = 'Εγγραφή';
$lang['AdminMain.add.field_add'] = 'Προσθήκη τομέα';
$lang['AdminMain.add.field_lookup'] = 'Ελέγξτε τη διαθεσιμότητα';
$lang['AdminMain.add.field_submit'] = 'Συνεχίστε';
$lang['AdminMain.add.field_invoice_method'] = 'Μέθοδος τιμολόγησης';
$lang['AdminMain.add.field_invoice_method_create'] = 'Δημιουργία νέου τιμολογίου';
$lang['AdminMain.add.field_invoice_method_append'] = 'Προσάρτηση σε υπάρχον τιμολόγιο';
$lang['AdminMain.add.field_invoice_method_dont'] = 'Μην τιμολογείτε';
$lang['AdminMain.add.field_years'] = 'Έτη';
$lang['AdminMain.add.field_status'] = 'Κατάσταση';
$lang['AdminMain.add.field_module'] = 'Μονάδα καταχωρητή';
$lang['AdminMain.add.field_use_module'] = 'Παροχή του τομέα μέσω της ενότητας καταχωρητή όταν ενεργοποιηθεί';
$lang['AdminMain.add.field_notify_order'] = 'Αποστολή email επιβεβαίωσης παραγγελίας όταν ενεργοποιηθεί';
$lang['AdminMain.add.title_search_results'] = 'Αποτελέσματα αναζήτησης';
$lang['AdminMain.add.title_basic_options'] = 'Βασικές επιλογές';
$lang['AdminMain.add.title_registrar_options'] = 'Επιλογές καταχωρητή';
$lang['AdminMain.add.heading_domain'] = 'Τομέας';
$lang['AdminMain.add.heading_status'] = 'Κατάσταση';
$lang['AdminMain.add.heading_options'] = 'Επιλογές';
$lang['AdminMain.add.text_domain_available'] = 'Διαθέσιμο';
$lang['AdminMain.add.text_domain_unavailable'] = 'Μη διαθέσιμο';
$lang['AdminMain.add.term_day'] = '%1$s Ημέρα';
$lang['AdminMain.add.term_days'] = '%1$s Ημέρες';
$lang['AdminMain.add.term_week'] = '%1$s Εβδομάδα';
$lang['AdminMain.add.term_weeks'] = '%1$s Εβδομάδες';
$lang['AdminMain.add.term_month'] = '%1$s Μήνας';
$lang['AdminMain.add.term_months'] = '%1$s Μήνες';
$lang['AdminMain.add.term_year'] = '%1$s Έτος';
$lang['AdminMain.add.term_years'] = '%1$s Έτη';
$lang['AdminMain.add.order_btn'] = 'Επιλεγμένη παραγγελία';
$lang['AdminMain.add.term'] = '%1$s @ %2$s';
$lang['AdminMain.add.term_recurring'] = '%1$s @ %2$s (ανανεώνεται @ %3$s)';
$lang['AdminMain.add.edit_package_pricing'] = 'Επεξεργασία τιμολόγησης';
$lang['AdminMain.add_confirmation.field_invoice_method'] = 'Μέθοδος τιμολόγησης:';
$lang['AdminMain.add_confirmation.field_invoice_method_create'] = 'Δημιουργία νέου τιμολογίου';
$lang['AdminMain.add_confirmation.field_invoice_method_append'] = 'Προσάρτηση στο τιμολόγιο %1$s';
$lang['AdminMain.add_confirmation.field_invoice_method_dont'] = 'Μην τιμολογείτε';
$lang['AdminMain.add_confirmation.field_status'] = 'Κατάσταση:';
$lang['AdminMain.add_confirmation.field_module'] = 'Ενότητα γραμματέα:';
$lang['AdminMain.add_confirmation.field_notify_order'] = 'Αποστολή email επιβεβαίωσης παραγγελίας:';
$lang['AdminMain.add_confirmation.field_notify_order_true'] = 'Ναι';
$lang['AdminMain.add_confirmation.field_notify_order_false'] = 'Όχι';
$lang['AdminMain.add_confirmation.field_domain'] = 'Τομέας:';
$lang['AdminMain.add_confirmation.field_years'] = 'Έτη:';
$lang['AdminMain.add_confirmation.field_type'] = 'Τύπος:';
$lang['AdminMain.add_confirmation.field_price'] = 'Τιμή:';
$lang['AdminMain.add_confirmation.field_coupon_code'] = 'Κωδικός κουπονιού';
$lang['AdminMain.add_confirmation.field_update_coupon'] = 'Ενημέρωση';
$lang['AdminMain.add_confirmation.field_add'] = 'Προσθήκη τομέα';
$lang['AdminMain.add_confirmation.field_edit'] = 'Επεξεργασία';
$lang['AdminMain.add_confirmation.type_register'] = 'Εγγραφή';
$lang['AdminMain.add_confirmation.type_transfer'] = 'Μεταφορά';
$lang['AdminMain.add_confirmation.description'] = 'Περιγραφή';
$lang['AdminMain.add_confirmation.qty'] = 'Ποσότητα';
$lang['AdminMain.add_confirmation.price'] = 'Τιμή';
$lang['AdminMain.add_confirmation.subtotal'] = 'Υποσύνολο:';
$lang['AdminMain.add_confirmation.discount'] = 'Έκπτωση:';
$lang['AdminMain.edit.boxtitle_client'] = 'Πελάτης #%1$s';
$lang['AdminMain.edit.boxtitle_edit'] = 'Επεξεργασία τομέα: %1$s';
$lang['AdminMain.edit.link_viewclient'] = 'Προβολή πελάτη';
$lang['AdminMain.edit.field_action'] = 'Δράση';
$lang['AdminMain.edit.field_years'] = 'Έτη';
$lang['AdminMain.edit.field_auto_renewal'] = 'Ενεργοποίηση αυτόματης ανανέωσης';
$lang['AdminMain.edit.field_ns1'] = 'Διακομιστής ονομάτων 1';
$lang['AdminMain.edit.field_ns2'] = 'Διακομιστής ονομάτων 2';
$lang['AdminMain.edit.field_ns3'] = 'Διακομιστής ονομάτων 3';
$lang['AdminMain.edit.field_ns4'] = 'Διακομιστής ονομάτων 4';
$lang['AdminMain.edit.field_ns5'] = 'Διακομιστής ονομάτων 5';
$lang['AdminMain.edit.field_client'] = 'Πελάτης';
$lang['AdminMain.edit.field_module'] = 'Μονάδα καταχωρητή';
$lang['AdminMain.edit.field_use_module'] = 'Χρήση μονάδας';
$lang['AdminMain.edit.field_notify_order'] = 'Αποστολή email επιβεβαίωσης παραγγελίας όταν ενεργοποιηθεί';
$lang['AdminMain.edit.field_submit'] = 'Ενημέρωση';
$lang['AdminMain.edit.field_activate'] = 'Ενεργοποίηση';
$lang['AdminMain.edit.field_edit_service'] = 'Επεξεργασία υπηρεσίας';
$lang['AdminMain.edit.text_domain'] = 'Τομέας:';
$lang['AdminMain.edit.text_registrar'] = 'Ληξίαρχος:';
$lang['AdminMain.edit.text_years'] = 'Εγγεγραμμένα έτη:';
$lang['AdminMain.edit.text_status'] = 'Κατάσταση:';
$lang['AdminMain.edit.text_date_added'] = 'Ημερομηνία δημιουργίας:';
$lang['AdminMain.edit.text_date_renews'] = 'Η ημερομηνία ανανεώνεται:';
$lang['AdminMain.edit.text_date_expires'] = 'Ημερομηνία λήξης:';
$lang['AdminMain.edit.text_never'] = 'Ποτέ';
$lang['AdminMain.edit.text_date_last_renewed'] = 'Τελευταία ημερομηνία ανανέωσης:';
$lang['AdminMain.edit.text_date_suspended'] = 'Ημερομηνία αναστολής:';
$lang['AdminMain.edit.text_date_canceled'] = 'Ημερομηνία ακύρωσης:';
$lang['AdminMain.edit.term_day'] = '%1$s Ημέρα';
$lang['AdminMain.edit.term_days'] = '%1$s Ημέρες';
$lang['AdminMain.edit.term_week'] = '%1$s Εβδομάδα';
$lang['AdminMain.edit.term_weeks'] = '%1$s Εβδομάδες';
$lang['AdminMain.edit.term_month'] = '%1$s Μήνας';
$lang['AdminMain.edit.term_months'] = '%1$s Μήνες';
$lang['AdminMain.edit.term_year'] = '%1$s Έτος';
$lang['AdminMain.edit.term_years'] = '%1$s Έτη';
$lang['AdminMain.edit.title_domain_information'] = 'Πληροφορίες τομέα';
$lang['AdminMain.edit.title_actions'] = 'Δράσεις';
$lang['AdminMain.edit.title_basic_options'] = 'Βασικές επιλογές';
$lang['AdminMain.getmodulefields.auto_choose'] = '-- Επιλέξτε Αυτόματα --';
$lang['AdminMain.edit.text_registration_date'] = 'Ημερομηνία καταχώρισης:';
$lang['AdminMain.index.text_date_added'] = 'Ημερομηνία προσθήκης::';
$lang['AdminMain.index.heading_dateregistration'] = 'Ημερομηνία καταχώρισης';
$lang['AdminMain.index.heading_registrar'] = 'Καταχωρητής';
$lang['AdminMain.!success.domain_registrar_updated'] = 'Ο καταχωρητής domain έχει ενημερωθεί!';

==> blesta-5.11.4.zip: blesta/plugins/domains/language/el_gr/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.el_gr
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.!success.change_auto_renewal'] = 'Η αυτόματη ανανέωση domain έχει ενημερωθεί!';
$lang['AdminMain.!success.domain_renewal'] = 'Ο τομέας ανανεώθηκε!';
$lang['AdminMain.!success.update_nameservers'] = 'Οι διακομιστές ονομάτων τομέα έχουν ενημερωθεί!';
$lang['AdminMain.!success.domains_pushed'] = 'Οι επιλεγμένοι τομείς μεταφέρθηκαν επιτυχώς στον νέο πελάτη.';
$lang['AdminMain.index.page_title'] = 'Πελάτης #%1$s Domains';
$lang['AdminMain.index.boxtitle_domains'] = 'Τομείς';
$lang['AdminMain.index.heading_addons'] = 'Πρόσθετα';
$lang['AdminMain.index.heading_status'] = 'Κατάσταση';
$lang['AdminMain.index.heading_domain'] = 'Τομέας';
$lang['AdminMain.index.heading_term'] = 'Όρος';
$lang['AdminMain.index.heading_datecreated'] = 'Ημερομηνία δημιουργίας';
$lang['AdminMain.index.heading_daterenews'] = 'Ημερομηνία Ανανεώνει';
$lang['AdminMain.index.heading_dateexpires'] = 'Ημερομηνία Λήξης';
$lang['AdminMain.index.heading_datesuspended'] = 'Ημερομηνία αναστολής';
$lang['AdminMain.index.heading_datecanceled'] = 'Ημερομηνία Ακύρωσης';
$lang['AdminMain.index.heading_options'] = 'Επιλογές';
$lang['AdminMain.index.category_active'] = 'Ενεργό';
$lang['AdminMain.index.category_pending'] = 'Εκκρεμεί';
$lang['AdminMain.index.category_suspended'] = 'Αναστολή';
$lang['AdminMain.index.category_canceled'] = 'Ακυρώθηκε';
$lang['AdminMain.index.categorylink_newservice'] = 'Νέος τομέας';
$lang['AdminMain.index.recurring_term'] = '%1$s %2$s @ %3$s';
$lang['AdminMain.index.option_parent'] = 'Γονέας';
$lang['AdminMain.index.option_manage'] = 'Διαχείριση';
$lang['AdminMain.index.option_delete'] = 'Διαγραφή';
$lang['AdminMain.index.confirm_delete'] = 'Είστε σίγουροι ότι θέλετε να διαγράψετε αυτή την υπηρεσία;';
$lang['AdminMain.index.no_results'] = 'Δεν υπάρχουν υπηρεσίες με αυτό το καθεστώς.';
$lang['AdminMain.index.text_never'] = 'Ποτέ';
$lang['AdminMain.index.text_on'] = 'Στο';
$lang['AdminMain.index.text_off'] = 'Off';
$lang['AdminMain.index.change_auto_renewal'] = 'Αλλαγή αυτόματης ανανέωσης';
$lang['AdminMain.index.domain_renewal'] = 'Ανανέωση τομέα';
$lang['AdminMain.index.update_nameservers'] = 'Ενημέρωση διακομιστών ονομάτων';
$lang['AdminMain.index.domain_push_to_client'] = 'Πίεση στον πελάτη';
$lang['AdminMain.index.field_actionsubmit'] = 'Υποβολή';
$lang['AdminMain.domains.action.field_years'] = 'Έτη';
$lang['AdminMain.domains.action.field_nameservers'] = 'Διακομιστές ονομάτων';
$lang['AdminMain.domains.action.field_client'] = 'Πελάτης';
$lang['AdminMain.getfilters.any'] = 'Οποιοδήποτε';
$lang['AdminMain.getfilters.field_package_name'] = 'TLD';
$lang['AdminMain.getfilters.field_service_meta'] = 'Όνομα τομέα';
$lang['AdminMain.!success.domains_unparented'] = 'Τα επιλεγμένα domains αφαιρέθηκαν από τις γονικές τους υπηρεσίες και η τιμή επαναρυθμίστηκε με επιτυχία!';
$lang['AdminMain.!success.domain_register'] = 'Ο τομέας καταχωρήθηκε με επιτυχία!';
$lang['AdminMain.!success.domain_transfer'] = 'Ο τομέας μεταφέρθηκε με επιτυχία!';
$lang['AdminMain.!success.domain_add'] = 'Ο τομέας έχει προστεθεί επιτυχώς!';
$lang['AdminMain.!success.service_edited'] = 'Ο τομέας ενημερώθηκε με επιτυχία!';
$lang['AdminMain.!error.unsupported_domain'] = 'Το όνομα τομέα δεν υποστηρίζεται.';
$lang['AdminMain.index.unparent'] = 'Unparent και Επαναφορά τιμής';
$lang['AdminMain.add.boxtitle_client'] = 'Πελάτης #%1$s';
$lang['AdminMain.add.boxtitle_add'] = 'Προσθήκη τομέα: %1$s';
$lang['AdminMain.add.link_viewclient'] = 'Προβολή πελάτη';
$lang['AdminMain.add.field_transfer'] = 'Μεταφορά';
$lang['AdminMain.add.field_register'] = 'Εγγραφή';
$lang['AdminMain.add.field_add'] = 'Προσθήκη τομέα';
$lang['AdminMain.add.field_lookup'] = 'Ελέγξτε τη διαθεσιμότητα';
$lang['AdminMain.add.field_submit'] = 'Συνεχίστε';
$lang['AdminMain.add.field_invoice_method'] = 'Μέθοδος τιμολόγησης';
$lang['AdminMain.add.field_invoice_method_create'] = 'Δημιουργία νέου τιμολογίου';
$lang['AdminMain.add.field_invoice_method_append'] = 'Προσάρτηση σε υπάρχον τιμολόγιο';
$lang['AdminMain.add.field_invoice_method_dont'] = 'Μην τιμολογείτε';
$lang['AdminMain.add.field_years'] = 'Έτη';
$lang['AdminMain.add.field_status'] = 'Κατάσταση';
$lang['AdminMain.add.field_module'] = 'Μονάδα καταχωρητή';
$lang['AdminMain.add.field_use_module'] = 'Παροχή του τομέα μέσω της ενότητας καταχωρητή όταν ενεργοποιηθεί';
$lang['AdminMain.add.field_notify_order'] = 'Αποστολή email επιβεβαίωσης παραγγελίας όταν ενεργοποιηθεί';
$lang['AdminMain.add.title_search_results'] = 'Αποτελέσματα αναζήτησης';
$lang['AdminMain.add.title_basic_options'] = 'Βασικές επιλογές';
$lang['AdminMain.add.title_registrar_options'] = 'Επιλογές καταχωρητή';
$lang['AdminMain.add.heading_domain'] = 'Τομέας';
$lang['AdminMain.add.heading_status'] = 'Κατάσταση';
$lang['AdminMain.add.heading_options'] = 'Επιλογές';
$lang['AdminMain.add.text_domain_available'] = 'Διαθέσιμο';
$lang['AdminMain.add.text_domain_unavailable'] = 'Μη διαθέσιμο';
$lang['AdminMain.add.term_day'] = '%1$s Ημέρα';
$lang['AdminMain.add.term_days'] = '%1$s Ημέρες';
$lang['AdminMain.add.term_week'] = '%1$s Εβδομάδα';
$lang['AdminMain.add.term_weeks'] = '%1$s Εβδομάδες';
$lang['AdminMain.add.term_month'] = '%1$s Μήνας';
$lang['AdminMain.add.term_months'] = '%1$s Μήνες';
$lang['AdminMain.add.term_year'] = '%1$s Έτος';
$lang['AdminMain.add.term_years'] = '%1$s Έτη';
$lang['AdminMain.add.order_btn'] = 'Επιλεγμένη παραγγελία';
$lang['AdminMain.add.term'] = '%1$s @ %2$s';
$lang['AdminMain.add.term_recurring'] = '%1$s @ %2$s (ανανεώνεται @ %3$s)';
$lang['AdminMain.add.edit_package_pricing'] = 'Επεξεργασία τιμολόγησης';
$lang['AdminMain.add_confirmation.field_invoice_method'] = 'Μέθοδος τιμολόγησης:';
$lang['AdminMain.add_confirmation.field_invoice_method_create'] = 'Δημιουργία νέου τιμολογίου';
$lang['AdminMain.add_confirmation.field_invoice_method_append'] = 'Προσάρτηση στο τιμολόγιο %1$s';
$lang['AdminMain.add_confirmation.field_invoice_method_dont'] = 'Μην τιμολογείτε';
$lang['AdminMain.add_confirmation.field_status'] = 'Κατάσταση:';
$lang['AdminMain.add_confirmation.field_module'] = 'Ενότητα γραμματέα:';
$lang['AdminMain.add_confirmation.field_notify_order'] = 'Αποστολή email επιβεβαίωσης παραγγελίας:';
$lang['AdminMain.add_confirmation.field_notify_order_true'] = 'Ναι';
$lang['AdminMain.add_confirmation.field_notify_order_false'] = 'Όχι';
$lang['AdminMain.add_confirmation.field_domain'] = 'Τομέας:';
$lang['AdminMain.add_confirmation.field_years'] = 'Έτη:';
$lang['AdminMain.add_confirmation.field_type'] = 'Τύπος:';
$lang['AdminMain.add_confirmation.field_price'] = 'Τιμή:';
$lang['AdminMain.add_confirmation.field_coupon_code'] = 'Κωδικός κουπονιού';
$lang['AdminMain.add_confirmation.field_update_coupon'] = 'Ενημέρωση';
$lang['AdminMain.add_confirmation.field_add'] = 'Προσθήκη τομέα';
$lang['AdminMain.add_confirmation.field_edit'] = 'Επεξεργασία';
$lang['AdminMain.add_confirmation.type_register'] = 'Εγγραφή';
$lang['AdminMain.add_confirmation.type_transfer'] = 'Μεταφορά';
$lang['AdminMain.add_confirmation.description'] = 'Περιγραφή';
$lang['AdminMain.add_confirmation.qty'] = 'Ποσότητα';
$lang['AdminMain.add_confirmation.price'] = 'Τιμή';
$lang['AdminMain.add_confirmation.subtotal'] = 'Υποσύνολο:';
$lang['AdminMain.add_confirmation.discount'] = 'Έκπτωση:';
$lang['AdminMain.edit.boxtitle_client'] = 'Πελάτης #%1$s';
$lang['AdminMain.edit.boxtitle_edit'] = 'Επεξεργασία τομέα: %1$s';
$lang['AdminMain.edit.link_viewclient'] = 'Προβολή πελάτη';
$lang['AdminMain.edit.field_action'] = 'Δράση';
$lang['AdminMain.edit.field_years'] = 'Έτη';
$lang['AdminMain.edit.field_auto_renewal'] = 'Ενεργοποίηση αυτόματης ανανέωσης';
$lang['AdminMain.edit.field_ns1'] = 'Διακομιστής ονομάτων 1';
$lang['AdminMain.edit.field_ns2'] = 'Διακομιστής ονομάτων 2';
$lang['AdminMain.edit.field_ns3'] = 'Διακομιστής ονομάτων 3';
$lang['AdminMain.edit.field_ns4'] = 'Διακομιστής ονομάτων 4';
$lang['AdminMain.edit.field_ns5'] = 'Διακομιστής ονομάτων 5';
$lang['AdminMain.edit.field_client'] = 'Πελάτης';
$lang['AdminMain.edit.field_module'] = 'Μονάδα καταχωρητή';
$lang['AdminMain.edit.field_use_module'] = 'Χρήση μονάδας';
$lang['AdminMain.edit.field_notify_order'] = 'Αποστολή email επιβεβαίωσης παραγγελίας όταν ενεργοποιηθεί';
$lang['AdminMain.edit.field_submit'] = 'Ενημέρωση';
$lang['AdminMain.edit.field_activate'] = 'Ενεργοποίηση';
$lang['AdminMain.edit.field_edit_service'] = 'Επεξεργασία υπηρεσίας';
$lang['AdminMain.edit.text_domain'] = 'Τομέας:';
$lang['AdminMain.edit.text_registrar'] = 'Ληξίαρχος:';
$lang['AdminMain.edit.text_years'] = 'Εγγεγραμμένα έτη:';
$lang['AdminMain.edit.text_status'] = 'Κατάσταση:';
$lang['AdminMain.edit.text_date_added'] = 'Ημερομηνία δημιουργίας:';
$lang['AdminMain.edit.text_date_renews'] = 'Η ημερομηνία ανανεώνεται:';
$lang['AdminMain.edit.text_date_expires'] = 'Ημερομηνία λήξης:';
$lang['AdminMain.edit.text_never'] = 'Ποτέ';
$lang['AdminMain.edit.text_date_last_renewed'] = 'Τελευταία ημερομηνία ανανέωσης:';
$lang['AdminMain.edit.text_date_suspended'] = 'Ημερομηνία αναστολής:';
$lang['AdminMain.edit.text_date_canceled'] = 'Ημερομηνία ακύρωσης:';
$lang['AdminMain.edit.term_day'] = '%1$s Ημέρα';
$lang['AdminMain.edit.term_days'] = '%1$s Ημέρες';
$lang['AdminMain.edit.term_week'] = '%1$s Εβδομάδα';
$lang['AdminMain.edit.term_weeks'] = '%1$s Εβδομάδες';
$lang['AdminMain.edit.term_month'] = '%1$s Μήνας';
$lang['AdminMain.edit.term_months'] = '%1$s Μήνες';
$lang['AdminMain.edit.term_year'] = '%1$s Έτος';
$lang['AdminMain.edit.term_years'] = '%1$s Έτη';
$lang['AdminMain.edit.title_domain_information'] = 'Πληροφορίες τομέα';
$lang['AdminMain.edit.title_actions'] = 'Δράσεις';
$lang['AdminMain.edit.title_basic_options'] = 'Βασικές επιλογές';
$lang['AdminMain.getmodulefields.auto_choose'] = '-- Επιλέξτε Αυτόματα --';
$lang['AdminMain.edit.text_registration_date'] = 'Ημερομηνία καταχώρισης:';
$lang['AdminMain.index.text_date_added'] = 'Ημερομηνία προσθήκης::';
$lang['AdminMain.index.heading_dateregistration'] = 'Ημερομηνία καταχώρισης';
$lang['AdminMain.index.heading_registrar'] = 'Καταχωρητής';
$lang['AdminMain.!success.domain_registrar_updated'] = 'Ο καταχωρητής domain έχει ενημερωθεί!';
$lang['AdminMain.edit.field_registration_date'] = 'Αλλαγή ημερομηνίας εγγραφής';
$lang['AdminMain.edit.field_expiration_date'] = 'Αλλαγή Ημερομηνία λήξης';
$lang['AdminMain.!success.change_registration_date'] = 'Η ημερομηνία καταχώρισης του τομέα έχει ενημερωθεί!';
$lang['AdminMain.!success.change_expiration_date'] = 'Η ημερομηνία λήξης του τομέα έχει ενημερωθεί!';
